"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.cliOptionsTypes = exports.rcOptionsTypes = exports.commandNames = void 0;
const path_1 = __importDefault(require("path"));
const client_1 = require("@pnpm/client");
const error_1 = require("@pnpm/error");
const store_path_1 = require("@pnpm/store-path");
const store_cafs_1 = require("@pnpm/store.cafs");
const pick_registry_for_package_1 = require("@pnpm/pick-registry-for-package");
const parse_wanted_dependency_1 = require("@pnpm/parse-wanted-dependency");
const sort_keys_1 = __importDefault(require("sort-keys"));
const load_json_file_1 = __importDefault(require("load-json-file"));
const render_help_1 = __importDefault(require("render-help"));
exports.commandNames = ['cat-index'];
exports.rcOptionsTypes = cliOptionsTypes;
function cliOptionsTypes() {
    return {};
}
exports.cliOptionsTypes = cliOptionsTypes;
function help() {
    return (0, render_help_1.default)({
        description: 'Prints the index file of a specific package from the store.',
        descriptionLists: [],
        usages: ['pnpm cat-index <pkg name>@<pkg version>'],
    });
}
exports.help = help;
async function handler(opts, params) {
    if (!params || params.length === 0) {
        throw new error_1.PnpmError('MISSING_PACKAGE_NAME', 'Specify a package', {
            hint: help(),
        });
    }
    const wantedDependency = params[0];
    const { alias, pref } = (0, parse_wanted_dependency_1.parseWantedDependency)(wantedDependency) || {};
    if (!alias) {
        throw new error_1.PnpmError('INVALID_SELECTOR', `Cannot parse the "${wantedDependency}" selector`);
    }
    const storeDir = await (0, store_path_1.getStorePath)({
        pkgRoot: process.cwd(),
        storePath: opts.storeDir,
        pnpmHomeDir: opts.pnpmHomeDir,
    });
    const cafsDir = path_1.default.join(storeDir, 'files');
    const resolve = (0, client_1.createResolver)({
        ...opts,
        authConfig: opts.rawConfig,
    });
    const pkgSnapshot = await resolve({ alias, pref }, {
        lockfileDir: opts.lockfileDir ?? opts.dir,
        preferredVersions: {},
        projectDir: opts.dir,
        registry: (0, pick_registry_for_package_1.pickRegistryForPackage)(opts.registries, alias, pref),
    });
    const filesIndexFile = (0, store_cafs_1.getFilePathInCafs)(cafsDir, pkgSnapshot.resolution.integrity.toString(), 'index');
    try {
        const pkgFilesIndex = await (0, load_json_file_1.default)(filesIndexFile);
        return JSON.stringify((0, sort_keys_1.default)(pkgFilesIndex, { deep: true }), null, 2);
    }
    catch {
        throw new error_1.PnpmError('INVALID_PACKAGE', 'No corresponding index file found. You can use pnpm list to see if the package is installed.');
    }
}
exports.handler = handler;
//# sourceMappingURL=catIndex.js.map